==> 0.1.0-rc.1.tar.gz: lib/src/room_kit/controller/imp/room_beauty_controller_impl.dart <==
// Copyright (c); 2014-2020 NetEase, Inc.
// All right reserved.

part of room_kit;



class _NEInRoomBeautyControllerImpl extends  NEInRoomBeautyController {
  final _InRoomData roomData;

  _NEInRoomBeautyControllerImpl(this.roomData);

  @override
  Future<NEResult<void>> enableBeauty(bool enable) async {
    return await super.enableBeauty(enable);
  }

  @override
  void release() {
    super.release();
  }
}

class _NEPreRoomBeautyControllerImpl extends NEPreRoomBeautyController
    with NERtcChannelEventCallback {
  static const _tag = '_NEPreRoomBeautyControllerImpl';

  @override
  Future<NEResult<void>> enableBeauty(bool enable) async {
    var result = NEResult.success();

    ///如果未开启，默认直接返回
    if (enable == _isEnabled) return NEResult.success();

    ///先初始化G2
    if (enable) {
      var rtcInit = (await NERoomMediaService.instance.initRtcEngine(
              rtcChannelEventCallback: this,
              mediaType: MediaType.preRoom,
              nrtcAppKey: UserProfile.nrtcAppKey!)) ==
          NERtcErrorCode.ok;
      if (rtcInit) await NERoomMediaService.instance.defaultConfig();
      result = !rtcInit
          ? NEResult(code: RoomErrorCode.notSupport)
          : NEResult.success();
      if (!result.isSuccess()) return result;
    }

    ///初始化美颜engine
    return super.enableBeauty(enable);
  }

  @override
  void release() {
    ///如果美颜初始化失败，则直接释放G2
    NERoomMediaService.instance.release(MediaType.preRoom,);
    super.release();
  }

  @override
  void onAudioHasHowling() {
    // TODO: implement onAudioHasHowling
  }

  @override
  void onAudioRecording(int code, String filePath) {
    // TODO: implement onAudioRecording
  }

  @override
  void onClientRoleChange(int oldRole, int newRole) {
    // TODO: implement onClientRoleChange
  }

  @override
  void onConnectionStateChanged(int state, int reason) {
    // TODO: implement onConnectionStateChanged
  }

  @override
  void onConnectionTypeChanged(int newConnectionType) {
    // TODO: implement onConnectionTypeChanged
  }

  @override
  void onDisconnect(int reason) {
    // TODO: implement onDisconnect
  }

  @override
  void onError(int code) {
    // TODO: implement onError
  }

  @override
  void onFirstAudioDataReceived(int uid) {
    // TODO: implement onFirstAudioDataReceived
  }

  @override
  void onFirstAudioFrameDecoded(int uid) {
    // TODO: implement onFirstAudioFrameDecoded
  }

  @override
  void onFirstVideoDataReceived(int uid) {
    // TODO: implement onFirstVideoDataReceived
  }

  @override
  void onFirstVideoFrameDecoded(int uid, int width, int height) {
    // TODO: implement onFirstVideoFrameDecoded
  }

  @override
  void onJoinChannel(int result, int channelId, int elapsed) {
    // TODO: implement onJoinChannel
  }

  @override
  void onLeaveChannel(int result) {
    // TODO: implement onLeaveChannel
  }

  @override
  void onLiveStreamState(String taskId, String pushUrl, int liveState) {
    // TODO: implement onLiveStreamState
  }

  @override
  void onLocalAudioVolumeIndication(int volume) {
    // TODO: implement onLocalAudioVolumeIndication
  }

  @override
  void onMediaRelayReceiveEvent(int event, int code, String channelName) {
    // TODO: implement onMediaRelayReceiveEvent
  }

  @override
  void onMediaRelayStatesChange(int state, String channelName) {
    // TODO: implement onMediaRelayStatesChange
  }

  @override
  void onReJoinChannel(int result) {
    // TODO: implement onReJoinChannel
  }

  @override
  void onReceiveSEIMsg(int userID, String seiMsg) {
    // TODO: implement onReceiveSEIMsg
  }

  @override
  void onReconnectingStart() {
    // TODO: implement onReconnectingStart
  }

  @override
  void onRemoteAudioVolumeIndication(
      List<NERtcAudioVolumeInfo> volumeList, int totalVolume) {
    // TODO: implement onRemoteAudioVolumeIndication
  }

  @override
  void onUserAudioMute(int uid, bool muted) {
    // TODO: implement onUserAudioMute
  }

  @override
  void onUserAudioStart(int uid) {
    // TODO: implement onUserAudioStart
  }

  @override
  void onUserAudioStop(int uid) {
    // TODO: implement onUserAudioStop
  }

  @override
  void onUserJoined(int uid) {
    // TODO: implement onUserJoined
  }

  @override
  void onUserLeave(int uid, int reason) {
    // TODO: implement onUserLeave
  }

  @override
  void onUserSubStreamVideoStart(int uid, int maxProfile) {
    // TODO: implement onUserSubStreamVideoStart
  }

  @override
  void onUserSubStreamVideoStop(int uid) {
    // TODO: implement onUserSubStreamVideoStop
  }

  @override
  void onUserVideoMute(int uid, bool muted) {
    // TODO: implement onUserVideoMute
  }

  @override
  void onUserVideoProfileUpdate(int uid, int maxProfile) {
    // TODO: implement onUserVideoProfileUpdate
  }

  @override
  void onUserVideoStart(int uid, int maxProfile) {
    // TODO: implement onUserVideoStart
  }

  @override
  void onUserVideoStop(int uid) {
    // TODO: implement onUserVideoStop
  }

  @override
  void onWarning(int code) {
    // TODO: implement onWarning
  }

  @override
  void onLocalPublishFallbackToAudioOnly(bool isFallback, int streamType) {
    // TODO: implement onLocalPublishFallbackToAudioOnly
  }

  @override
  void onRemoteSubscribeFallbackToAudioOnly(int uid, bool isFallback, int streamType) {
    // TODO: implement onRemoteSubscribeFallbackToAudioOnly
  }
}

==> 0.1.1-rc.0.tar.gz: lib/src/room_kit/controller/imp/room_beauty_controller_impl.dart <==
// Copyright (c); 2014-2020 NetEase, Inc.
// All right reserved.

part of room_kit;



class _NEInRoomBeautyControllerImpl extends  NEInRoomBeautyController {
  final _InRoomData roomData;

  _NEInRoomBeautyControllerImpl(this.roomData);

  @override
  Future<NEResult<void>> enableBeauty(bool enable) async {
    return await super.enableBeauty(enable);
  }

  @override
  void release() {
    super.release();
  }
}

class _NEPreRoomBeautyControllerImpl extends NEPreRoomBeautyController
    with NERtcChannelEventCallback {

  @override
  Future<NEResult<void>> enableBeauty(bool enable) async {
    var result = NEResult.success();

    ///如果未开启，默认直接返回
    if (enable == _isEnabled) return NEResult.success();

    ///先初始化G2
    if (enable) {
      var rtcInit = (await NERoomMediaService.instance.initRtcEngine(
              rtcChannelEventCallback: this,
              mediaType: MediaType.preRoom,
              nrtcAppKey: UserProfile.nrtcAppKey!)) ==
          NERtcErrorCode.ok;
      // if (rtcInit) await NERoomMediaService.instance.defaultConfig();
      result = !rtcInit
          ? NEResult(code: RoomErrorCode.notSupport)
          : NEResult.success();
      if (!result.isSuccess()) return result;
    }

    ///初始化美颜engine
    return super.enableBeauty(enable);
  }

  @override
  void release() {
    ///如果美颜初始化失败，则直接释放G2
    NERoomMediaService.instance.release(MediaType.preRoom,);
    super.release();
  }

  @override
  void onAudioHasHowling() {
    // TODO: implement onAudioHasHowling
  }

  @override
  void onAudioRecording(int code, String filePath) {
    // TODO: implement onAudioRecording
  }

  @override
  void onClientRoleChange(int oldRole, int newRole) {
    // TODO: implement onClientRoleChange
  }

  @override
  void onConnectionStateChanged(int state, int reason) {
    // TODO: implement onConnectionStateChanged
  }

  @override
  void onConnectionTypeChanged(int newConnectionType) {
    // TODO: implement onConnectionTypeChanged
  }

  @override
  void onDisconnect(int reason) {
    // TODO: implement onDisconnect
  }

  @override
  void onError(int code) {
    // TODO: implement onError
  }

  @override
  void onFirstAudioDataReceived(int uid) {
    // TODO: implement onFirstAudioDataReceived
  }

  @override
  void onFirstAudioFrameDecoded(int uid) {
    // TODO: implement onFirstAudioFrameDecoded
  }

  @override
  void onFirstVideoDataReceived(int uid) {
    // TODO: implement onFirstVideoDataReceived
  }

  @override
  void onFirstVideoFrameDecoded(int uid, int width, int height) {
    // TODO: implement onFirstVideoFrameDecoded
  }

  @override
  void onJoinChannel(int result, int channelId, int elapsed) {
    // TODO: implement onJoinChannel
  }

  @override
  void onLeaveChannel(int result) {
    // TODO: implement onLeaveChannel
  }

  @override
  void onLiveStreamState(String taskId, String pushUrl, int liveState) {
    // TODO: implement onLiveStreamState
  }

  @override
  void onLocalAudioVolumeIndication(int volume) {
    // TODO: implement onLocalAudioVolumeIndication
  }

  @override
  void onMediaRelayReceiveEvent(int event, int code, String channelName) {
    // TODO: implement onMediaRelayReceiveEvent
  }

  @override
  void onMediaRelayStatesChange(int state, String channelName) {
    // TODO: implement onMediaRelayStatesChange
  }

  @override
  void onReJoinChannel(int result) {
    // TODO: implement onReJoinChannel
  }

  @override
  void onReceiveSEIMsg(int userID, String seiMsg) {
    // TODO: implement onReceiveSEIMsg
  }

  @override
  void onReconnectingStart() {
    // TODO: implement onReconnectingStart
  }

  @override
  void onRemoteAudioVolumeIndication(
      List<NERtcAudioVolumeInfo> volumeList, int totalVolume) {
    // TODO: implement onRemoteAudioVolumeIndication
  }

  @override
  void onUserAudioMute(int uid, bool muted) {
    // TODO: implement onUserAudioMute
  }

  @override
  void onUserAudioStart(int uid) {
    // TODO: implement onUserAudioStart
  }

  @override
  void onUserAudioStop(int uid) {
    // TODO: implement onUserAudioStop
  }

  @override
  void onUserJoined(int uid) {
    // TODO: implement onUserJoined
  }

  @override
  void onUserLeave(int uid, int reason) {
    // TODO: implement onUserLeave
  }

  @override
  void onUserSubStreamVideoStart(int uid, int maxProfile) {
    // TODO: implement onUserSubStreamVideoStart
  }

  @override
  void onUserSubStreamVideoStop(int uid) {
    // TODO: implement onUserSubStreamVideoStop
  }

  @override
  void onUserVideoMute(int uid, bool muted) {
    // TODO: implement onUserVideoMute
  }

  @override
  void onUserVideoProfileUpdate(int uid, int maxProfile) {
    // TODO: implement onUserVideoProfileUpdate
  }

  @override
  void onUserVideoStart(int uid, int maxProfile) {
    // TODO: implement onUserVideoStart
  }

  @override
  void onUserVideoStop(int uid) {
    // TODO: implement onUserVideoStop
  }

  @override
  void onWarning(int code) {
    // TODO: implement onWarning
  }

  @override
  void onLocalPublishFallbackToAudioOnly(bool isFallback, int streamType) {
    // TODO: implement onLocalPublishFallbackToAudioOnly
  }

  @override
  void onRemoteSubscribeFallbackToAudioOnly(int uid, bool isFallback, int streamType) {
    // TODO: implement onRemoteSubscribeFallbackToAudioOnly
  }

  @override
  Future<NERtcVideoRenderer?> createVideoPreview() {
    return NERoomMediaService.instance.createVideoPreview();
  }
}
